@@ -124,7 +124,7 @@ static int LinuxDriverAPMstate = APM_STATE_READY;
 #ifdef VMX86_DEVEL
 #define TAGNAME "(development)"
 #else
-#define TAGNAME "$Name: vmware-netbsd-3-2-1-4 $"
+#define TAGNAME "$Name: vmware-netbsd-3-2-2 $"
 #endif
 
 struct VMXLinuxState linuxState;
