@@ -33,10 +33,6 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifdef _KERNEL_OPT
-#include "opt_multiprocessor.h"
-#endif
-
 #include <sys/param.h>
 #include <sys/conf.h>
 #include <sys/filedesc.h>
@@ -79,15 +75,6 @@
 #define	CURLWP		curproc		/* old world order */
 #endif
 
-/* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ == 106220000
-#define ENTRYARG	lwp
-#define LWP2PROC(l)	(l->l_proc)
-#else
-#define ENTRYARG	proc
-#define LWP2PROC(l)	(l)
-#endif
-
 #define FILECODE "F(300)"
 
 #include "x86.h"
@@ -113,20 +100,16 @@
 
 #define VMDEBUG  if (vmmon_debug) printf
 
-#ifndef _LKM
-void vmmonattach(int);
-#else
 int vmmon_lkmentry(struct lkm_table *, int, int);
 static int vmmon_handle(struct lkm_table *, int);
-#endif /* _LKM */
 
-static int vmmon_open(dev_t dev, int oflags, int devtype, struct ENTRYARG *);
-static int vmmon_close(dev_t dev, int cflags, int devtype, struct ENTRYARG*);
+static int vmmon_open(dev_t dev, int oflags, int devtype, struct proc *p);
+static int vmmon_close(dev_t dev, int cflags, int devtype, struct proc *p);
 static int vmmon_ioctl(dev_t dev, u_long cmd, caddr_t data, int flags,
-		 struct ENTRYARG *);
-static int vmmon_poll(dev_t, int, struct ENTRYARG *);
+		 struct proc *p);
+static int vmmon_poll(dev_t, int, struct proc *);
 
-static int vmmon_fake_clonedev(dev_t, int, struct ENTRYARG *);
+static int vmmon_fake_clonedev(dev_t, int, struct proc *);
 
 static int vm_create(struct vmmon_softc *, struct vmx86_softc **);
 static struct vmx86_softc * vm_allocate(struct vmmon_softc *);
@@ -140,7 +123,7 @@ static void vmmon_destroy_low_pages(MemRange *);
 
 struct vmmon_softc vmmon_sc;
 
-struct cdevsw vmmon_cdevsw = {
+static struct cdevsw vmmon_dev = {
 	vmmon_open, vmmon_close, 
 	(dev_type_read((*)))enodev, (dev_type_write((*)))enodev,
 	vmmon_ioctl, (dev_type_stop((*))) enodev, 0,
@@ -150,11 +133,11 @@ struct cdevsw vmmon_cdevsw = {
 static int vmmon_refcnt = 0;
 static int vmmon_debug = 0;
 
-#ifdef _LKM
+
 #if __NetBSD_Version__ >= 106080000
-MOD_DEV("vmmon", "vmmon", NULL, -1, &vmmon_cdevsw, -1)
+MOD_DEV("vmmon", "vmmon", NULL, -1, &vmmon_dev, -1)
 #else
-MOD_DEV("vmmon", LM_DT_CHAR, -1, &vmmon_cdevsw)
+MOD_DEV("vmmon", LM_DT_CHAR, -1, &vmmon_dev)
 #endif
 
 int
@@ -193,28 +176,20 @@ vmmon_handle(struct lkm_table *lkmtp, int cmd)
 	}
 	return error;
 }
-#else /* !_LKM */
-void
-vmmonattach(int ndevs)
-{
-	CPUID_Init();
-	Task_ProbeSysenterMSR();
-}
-#endif /* _LKM */
 
 static int
-vmmon_open(dev_t dev, int flag, int mode, struct ENTRYARG *l)
+vmmon_open(dev_t dev, int flag, int mode, struct proc *p)
 {
 	struct vmmon_softc *vmmonsc;
 	struct vmx86_softc *vmxsc;
 	int error;
 
-	if (LWP2PROC(l)->p_dupfd >= 0)
+	if (p->p_dupfd >= 0)
 		return ENODEV;
 
-	VMDEBUG("vmmon: %d opened device\n", LWP2PROC(l)->p_pid);
+	VMDEBUG("vmmon: %d opened device\n", p->p_pid);
 
-	if (suser(LWP2PROC(l)->p_ucred, &LWP2PROC(l)->p_acflag) != 0)
+	if (suser(p->p_ucred, &p->p_acflag) != 0)
 		return (EPERM);
 
 	vmmonsc = &vmmon_sc;
@@ -228,10 +203,10 @@ vmmon_open(dev_t dev, int flag, int mode, struct ENTRYARG *l)
 	vmmon_refcnt++;
 
 	VMDEBUG("vmmon: pid %d new vm: num %d major %d\n",
-	    LWP2PROC(l)->p_pid, VMNUM(vmxsc->vm_dev), major(vmxsc->vm_dev));
+	    p->p_pid, VMNUM(vmxsc->vm_dev), major(vmxsc->vm_dev));
 
-	error = vmmon_fake_clonedev(vmxsc->vm_dev, flag, l);
-	if (error != 0 && LWP2PROC(l)->p_dupfd < 0) {
+	error = vmmon_fake_clonedev(vmxsc->vm_dev, flag, p);
+	if (error != 0 && p->p_dupfd < 0) {
 		vm_destroy(vmmonsc, VMNUM(vmxsc->vm_dev));
 		return error;
 	}
@@ -248,14 +223,14 @@ vmmon_open(dev_t dev, int flag, int mode, struct ENTRYARG *l)
 
 
 static int
-vmmon_close(dev_t dev, int flags, int mode, struct ENTRYARG *l)
+vmmon_close(dev_t dev, int flags, int mode, struct proc *p)
 {
 	int num;
 	struct vmmon_softc *sc;
 	struct vmx86_softc *vmxsc;
 	MemRange *head, *first;
 
-	VMDEBUG("vmmon: close vm %d by pid %d\n", VMNUM(dev), LWP2PROC(l)->p_pid);
+	VMDEBUG("vmmon: close vm %d by pid %d\n", VMNUM(dev), p->p_pid);
 
 	sc = &vmmon_sc;
 
@@ -288,7 +263,7 @@ vmmon_close(dev_t dev, int flags, int mode, struct ENTRYARG *l)
 		printf("vmmon: refcnt < 0 ??\n");
 	}
 
-	VMDEBUG("vmmon: vm %d closed by %d\n", num, LWP2PROC(l)->p_pid);
+	VMDEBUG("vmmon: vm %d closed by %d\n", num, p->p_pid);
 
 	return (0);
 }
@@ -298,7 +273,7 @@ vmmon_close(dev_t dev, int flags, int mode, struct ENTRYARG *l)
  * XXXX - poor man's device cloning.
  */
 int
-vmmon_fake_clonedev(dev_t dev, int flag, struct ENTRYARG *l)
+vmmon_fake_clonedev(dev_t dev, int flag, struct proc *p)
 {
 	struct file *fp;
 	int error, fd;
@@ -308,7 +283,7 @@ vmmon_fake_clonedev(dev_t dev, int flag, struct ENTRYARG *l)
 		/* XXX */
 		return EINVAL;
 
-	error = falloc(LWP2PROC(l), &fp, &fd);
+	error = falloc(p, &fp, &fd);
 	if (error != 0)
 		return error;
 	error = cdevvp(dev, &vp);
@@ -327,9 +302,9 @@ vmmon_fake_clonedev(dev_t dev, int flag, struct ENTRYARG *l)
 	FILE_SET_MATURE(fp);
 #endif
 #endif
-	FILE_UNUSE(fp, l);
+	FILE_UNUSE(fp, p);
 
-	LWP2PROC(l)->p_dupfd = fd;
+	p->p_dupfd = fd;
 
 	return ENXIO;
 }
@@ -509,7 +484,7 @@ vmmon_destroy_low_pages(MemRange *r)
  * set syscall return values for the benefit of Linux emulation.
  */
 static int
-vmmon_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct ENTRYARG*l)
+vmmon_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct proc *p)
 {
 	struct vmx86_softc *vmxsc;
 	struct vmmon_softc *sc;
@@ -530,7 +505,7 @@ vmmon_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct ENTRYARG*l)
 #endif
 
 	VMDEBUG("vmmon: ioctl %lx on vm %d by pid %d\n",
-	    cmd, VMNUM(dev), LWP2PROC(l)->p_pid);
+	    cmd, VMNUM(dev), p->p_pid);
 
 	sc = &vmmon_sc;
 
@@ -558,7 +533,7 @@ vmmon_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct ENTRYARG*l)
 		error = copyin(pt->data, &wslimitsInfo, sizeof wslimitsInfo);
 		if (error != 0)
 			return error;
-		vm = Vmx86_CreateVM((void *)&vmxsc, (void*)LWP2PROC(l)->p_pid,
+		vm = Vmx86_CreateVM((void *)&vmxsc, (void*)p->p_pid,
 		    &wslimitsInfo);
 		if (vm == NULL)
 			return ENOMEM;
@@ -786,7 +761,7 @@ vm_select_timo(void *arg)
 
 
 static int
-vmmon_poll(dev_t dev, int events, struct ENTRYARG *l)
+vmmon_poll(dev_t dev, int events, struct proc *p)
 {
 	struct vmmon_softc *sc;
 	struct vmx86_softc *vmxsc;
@@ -801,7 +776,7 @@ vmmon_poll(dev_t dev, int events, struct ENTRYARG *l)
 		return ENXIO;
 
 	VMDEBUG("vmmon: poll on vm %d by pid %d\n",
-	    VMNUM(dev), LWP2PROC(l)->p_pid);
+	    VMNUM(dev), p->p_pid);
 
 	s = splsoftclock();
 	if (vmxsc->vm_flags & VMFL_SELTIMO) {
@@ -810,7 +785,7 @@ vmmon_poll(dev_t dev, int events, struct ENTRYARG *l)
 	} else {
 		if (vmxsc->vm_flags & VMFL_SELWAIT)
 			callout_stop(&vmxsc->vm_callout);
-		selrecord(l, &vmxsc->vm_rsel);
+		selrecord(p, &vmxsc->vm_rsel);
 		vmxsc->vm_flags |= VMFL_SELWAIT;
 		callout_reset(&vmxsc->vm_callout, 1, vm_select_timo, vmxsc);
 	}
