@@ -33,12 +33,6 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifdef _KERNEL_OPT
-#include "bpfilter.h"
-#include "opt_inet.h"
-#include "opt_ns.h"
-#endif
-
 #include <sys/param.h>
 #include <sys/conf.h>
 #include <sys/filedesc.h>
@@ -100,37 +94,22 @@ static int ether_ioctl(struct ifnet *, u_long, caddr_t);
 #define	CURLWP		curproc		/* old world order */
 #endif
 
-/* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ == 106220000
-#define ENTRYARG	lwp
-#define LWP2PROC(l)	(l->l_proc)
-#else
-#define ENTRYARG	proc
-#define LWP2PROC(l)	(l)
-#endif
-
 extern struct vm_map *kernel_map;
 
 #define HUBDEBUG  if (hub_debug) printf
 
-#ifndef _LKM
-void vmnetattach(int);
-#else
 int vmnet_lkmentry(struct lkm_table *, int, int);
-#endif
 
-static int hub_open(dev_t dev, int oflags, int devtype, struct ENTRYARG *);
-static int hub_close(dev_t dev, int cflags, int devtype, struct ENTRYARG *);
+static int hub_open(dev_t dev, int oflags, int devtype, struct proc *p);
+static int hub_close(dev_t dev, int cflags, int devtype, struct proc *p);
 static int hub_ioctl(dev_t dev, u_long cmd, caddr_t data, int flags,
-		 struct ENTRYARG *);
+		 struct proc *p);
 static int hub_read(dev_t, struct uio *, int);
 static int hub_write(dev_t, struct uio *, int);
-static int hub_poll(dev_t, int, struct ENTRYARG *);
+static int hub_poll(dev_t, int, struct proc *);
 
 static int hub_ifinit(struct ifnet *);
-#ifdef _LKM
 static int hub_handle(struct lkm_table *, int);
-#endif
 static void hub_ifstart(struct ifnet *);
 static int hub_ifioctl(struct ifnet *, u_long, caddr_t);
 
@@ -144,7 +123,7 @@ static int port_mappoll(struct hubport_softc *, vaddr_t);
 static int port_unmappoll(struct hubport_softc *);
 
 static int hub_sendchain(struct hubport_softc *, struct mbuf *);
-static int hub_fake_clonedev(dev_t, int, struct ENTRYARG *);
+static int hub_fake_clonedev(dev_t, int, struct proc *);
 
 
 
@@ -152,6 +131,7 @@ static int hub_refcnt = 0;
 static int hub_debug = 0;
 static struct hubdev_softc *hub_scs[MAXHUBDEVS];
 
+
 /* genenna-devsw went into tree in 1.6H */
 #if __NetBSD_Version__ >= 106080000
 
@@ -163,9 +143,7 @@ const struct cdevsw vmnet_cdevsw = {
 	nostop, notty, hub_poll, nommap, nokqfilter, 0
 };
 
-#ifdef _LKM
 MOD_DEV("vmnet", "vmnet", NULL, -1, &vmnet_cdevsw, -1);
-#endif
 
 #else
 
@@ -177,21 +155,9 @@ static struct cdevsw hub_dev = {
 	hub_poll, (dev_type_mmap((*))) enodev, 0
 };
 
-#ifdef _LKM
 MOD_DEV("vmnet", LM_DT_CHAR, -1, &hub_dev);	/* old definition */
 #endif
 
-#endif
-
-#ifndef _LKM
-void
-vmnetattach(int ndev)
-{
-
-	/* Nothing to do */
-}
-
-#else /* _LKM */
 int
 vmnet_lkmentry(struct lkm_table *lkmtp, int cmd, int ver)
 {
@@ -204,14 +170,15 @@ hub_handle(struct lkm_table *lkmtp, int cmd)
 	int error = 0, i, j;
 	struct hubdev_softc *sc;
 #if __NetBSD_Version__ >= 105230000 || (__NetBSD_Version__ >= 105000100 && __NetBSD_Version__ < 105010000)
-	struct ifnet ifp;	/* XXX should be fine to use stack here */
+	struct ifnet *ifp;
 #endif
 	
 	switch (cmd) {
 	case LKM_E_LOAD:
 #if __NetBSD_Version__ >= 105230000 || (__NetBSD_Version__ >= 105000100 && __NetBSD_Version__ < 105010000)
-		ifp.if_mtu = ETHERMTU;
-		if (HUBMAXPKT(&ifp) > MCLBYTES) {
+ 		ifp = (struct ifnet *)malloc(sizeof(*ifp), M_MRTABLE, M_WAITOK);
+		ifp->if_mtu = ETHERMTU;
+		if (HUBMAXPKT(ifp) > MCLBYTES) {
 #else
 		if (HUBMAXPKT > MCLBYTES) {
 #endif
@@ -245,7 +212,6 @@ hub_handle(struct lkm_table *lkmtp, int cmd)
 	}
 	return error;
 }
-#endif /* _LKM */
 
 static void
 port_destroy(struct hubdev_softc *hubsc, int num)
@@ -472,24 +438,24 @@ port_unmappoll(struct hubport_softc *portsc)
 
 
 static int
-hub_open(dev_t dev, int flag, int mode, struct ENTRYARG *l)
+hub_open(dev_t dev, int flag, int mode, struct proc *p)
 {
 	struct hubdev_softc *hubsc;
 	struct hubport_softc *portsc;
 	int error, unit;
 
-	if (LWP2PROC(l)->p_dupfd >= 0)
+	if (p->p_dupfd >= 0)
 		return ENODEV;
 
 	unit = HUBUNIT(dev);
 
-	HUBDEBUG("if_hub: %d opened minor %d hub %d\n", LWP2PROC(l)->p_pid, minor(dev),
+	HUBDEBUG("if_hub: %d opened minor %d hub %d\n", p->p_pid, minor(dev),
 	    unit);
 
 	if (unit >= MAXHUBDEVS)
 		return (ENXIO);
 
-	if (suser(LWP2PROC(l)->p_ucred, &LWP2PROC(l)->p_acflag) != 0)
+	if (suser(p->p_ucred, &p->p_acflag) != 0)
 		return (EPERM);
 
 	hubsc = hub_scs[unit];
@@ -509,11 +475,11 @@ hub_open(dev_t dev, int flag, int mode, struct ENTRYARG *l)
 	hub_refcnt++;
 
 	HUBDEBUG("if_hub: pid %d new port: unit %d, port %d\n",
-	    LWP2PROC(l)->p_pid, HUBUNIT(portsc->port_dev),
+	    p->p_pid, HUBUNIT(portsc->port_dev),
 	    HUBPORT(portsc->port_dev));
 
-	error = hub_fake_clonedev(portsc->port_dev, flag, l);
-	if (error != 0 && LWP2PROC(l)->p_dupfd < 0)
+	error = hub_fake_clonedev(portsc->port_dev, flag, p);
+	if (error != 0 && p->p_dupfd < 0)
 		port_destroy(hubsc, HUBPORT(portsc->port_dev));
 
 	return error;
@@ -526,7 +492,7 @@ hub_open(dev_t dev, int flag, int mode, struct ENTRYARG *l)
  * close the device - mark i/f down & delete routing info
  */
 static int
-hub_close(dev_t dev, int flags, int mode, struct ENTRYARG *l)
+hub_close(dev_t dev, int flags, int mode, struct proc *p)
 {
 	int s, unit, port;
 	struct hubdev_softc *hubsc;
@@ -534,7 +500,7 @@ hub_close(dev_t dev, int flags, int mode, struct ENTRYARG *l)
 	struct mbuf *m;
 
 	HUBDEBUG("if_hub: close hub %d unit %d by pid %d\n",
-	    HUBUNIT(dev), HUBPORT(dev), LWP2PROC(l)->p_pid);
+	    HUBUNIT(dev), HUBPORT(dev), p->p_pid);
 	/*
 	 * The 2 cases below shouldn't ever happen.
 	 */
@@ -568,7 +534,7 @@ hub_close(dev_t dev, int flags, int mode, struct ENTRYARG *l)
 		printf("if_hub: refcnt < 0 ??\n");
 	}
 
-	HUBDEBUG("if_hub: hub %d port %d closed by %d\n", unit, port, LWP2PROC(l)->p_pid);
+	HUBDEBUG("if_hub: hub %d port %d closed by %d\n", unit, port, p->p_pid);
 
 	return (0);
 }
@@ -601,7 +567,7 @@ hub_ifioctl(struct ifnet *ifp, u_long cmd, caddr_t data)
  * XXXX - poor man's device cloning.
  */
 int
-hub_fake_clonedev(dev_t dev, int flag, struct ENTRYARG *l)
+hub_fake_clonedev(dev_t dev, int flag, struct proc *p)
 {
 	struct file *fp;
 	int error, fd;
@@ -611,7 +577,7 @@ hub_fake_clonedev(dev_t dev, int flag, struct ENTRYARG *l)
 		/* XXX */
 		return EINVAL;
 
-	error = falloc(LWP2PROC(l), &fp, &fd);
+	error = falloc(p, &fp, &fd);
 	if (error != 0)
 		return error;
 	error = cdevvp(dev, &vp);
@@ -630,9 +596,9 @@ hub_fake_clonedev(dev_t dev, int flag, struct ENTRYARG *l)
 	FILE_SET_MATURE(fp);
 #endif
 #endif
-	FILE_UNUSE(fp, l);
+	FILE_UNUSE(fp, p);
 
-	LWP2PROC(l)->p_dupfd = fd;
+	p->p_dupfd = fd;
 
 	return ENXIO;
 }
@@ -772,7 +738,7 @@ hub_ifstart(struct ifnet *ifp)
 
 
 static int
-hub_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct ENTRYARG *l)
+hub_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct proc *p)
 {
 	struct hubport_softc *portsc, *newport;
 	struct hubdev_softc *hubsc;
@@ -789,7 +755,7 @@ hub_ioctl(dev_t dev, u_long cmd, caddr_t data, int flag, struct ENTRYARG *l)
 	u_int32_t upolladdr, pollmask, dummy;
 
 	HUBDEBUG("if_hub: ioctl %lx on hub %d port %d by pid %d\n",
-	    cmd, HUBUNIT(dev), HUBPORT(dev), LWP2PROC(l)->p_pid);
+	    cmd, HUBUNIT(dev), HUBPORT(dev), p->p_pid);
 
 	hubsc = hub_scs[HUBUNIT(dev)];
 	if (hubsc == NULL)
@@ -1141,7 +1107,7 @@ hub_write(dev_t dev, struct uio *uio, int flag)
  * anyway, it either accepts the packet or drops it
  */
 static int
-hub_poll(dev_t dev, int events, struct ENTRYARG *l)
+hub_poll(dev_t dev, int events, struct proc *p)
 {
 	struct hubdev_softc *hubsc;
 	struct hubport_softc *portsc;
@@ -1155,14 +1121,14 @@ hub_poll(dev_t dev, int events, struct ENTRYARG *l)
 		return ENXIO;
 
 	HUBDEBUG("if_hub: poll on hub %d port %d by pid %d\n",
-	    HUBUNIT(dev), HUBPORT(dev), LWP2PROC(l)->p_pid);
+	    HUBUNIT(dev), HUBPORT(dev), p->p_pid);
 
 	s = splnet();
 	if (events & (POLLIN | POLLRDNORM)) {
 		if (portsc->port_rcvq.ifq_len > 0)
 			revents |= (events & (POLLIN | POLLRDNORM));
 		else
-			selrecord(l, &portsc->port_rsel);
+			selrecord(p, &portsc->port_rsel);
 	}
 
 	if (events & (POLLOUT | POLLWRNORM))
